aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java
diff options
context:
space:
mode:
authorGravatar olaola <olaola@google.com>2017-09-18 23:04:33 +0200
committerGravatar László Csomor <laszlocsomor@google.com>2017-09-19 09:32:25 +0200
commit7744b86e9c7950da62e87bfff3967c67477a1620 (patch)
treea6eaa8ca42c7df294ca2c2035b12d41e59a88e21 /src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java
parent8f9ace9bb6794e23ecac28ff70a9afebfc33ee12 (diff)
Uploading failed action outputs to the remote cache, because even if the tests fails, we still want to be able to download the logs and other outputs from CAS.
This fixes a bug introduced by https://github.com/bazelbuild/bazel/commit/562fcf9f5dfd14daea718f77da95b43b1400689b. To reproduce: run a failing test vs a BES service, the test log would not be uploaded. TESTED=unit tests PiperOrigin-RevId: 169143428
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java b/src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java
index 4c7cf7408a..d480a93b38 100644
--- a/src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java
+++ b/src/main/java/com/google/devtools/build/lib/remote/RemoteActionCache.java
@@ -75,9 +75,15 @@ interface RemoteActionCache {
/**
* Upload the result of a locally executed action to the cache by uploading any necessary files,
* stdin / stdout, as well as adding an entry for the given action key to the cache.
*/
- void upload(ActionKey actionKey, Path execRoot, Collection<Path> files, FileOutErr outErr)
+ void upload(
+ ActionKey actionKey,
+ Path execRoot,
+ Collection<Path> files,
+ FileOutErr outErr,
+ boolean uploadAction)
throws IOException, InterruptedException;
/** Release resources associated with the cache. The cache may not be used after calling this. */
@@ -75,9 +75,15 @@ interface RemoteActionCache {
/**
* Upload the result of a locally executed action to the cache by uploading any necessary files,
- * stdin / stdout, as well as adding an entry for the given action key to the cache.
+ * stdin / stdout, as well as adding an entry for the given action key to the cache if
+ * uploadAction is true.
*/